       IDENTIFICATION DIVISION.
       PROGRAM-ID. 'LISTVIEW'.
       DATE-COMPILED.
      *     This shell program was generated by the GS2000 program
      *     generator utility for use with GUI ScreenIO.
      *     For.........: Norcom
      *     By..........: Kevin J. Hansen
      *     Date Started:
      *
      *     Description.: Listview Event demonstrator.
      * 		:
      * 		: This program is intended to show how your
      * 		: program interacts with a listview control.
      * 		:
      * 		: It displays events and keys that are returned
      * 		: by the listview, and it simulates I/O to show
      * 		: how to load a listview, and how to work with
      * 		: it.
      * 		:
      * 		: It is helpful to use this to understand how
      * 		: a listview works.
      * 		:
      * 		: You can also experiment with the name/address
      * 		: listview demo application, which is provided
      * 		: with GUI ScreenIO, and which does real I/O
      * 		: with COBOL ISAM.
      *
       ENVIRONMENT DIVISION.
       CONFIGURATION SECTION.
       SOURCE-COMPUTER. IBM-PC.
       OBJECT-COMPUTER. IBM-PC.
      *%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
       DATA DIVISION.
       WORKING-STORAGE SECTION.
       01  PROGRAM-NAME 	     PIC X(8) VALUE 'LISTVIEW'.
      *
      * ------------------------: Copybooks for GUI ScreenIO panels.
      *
	   COPY LVMAIN.
	   COPY LVIEW.
      *
      * ------------------------: Keeps track of whether a listview is
      * 			: in ascending or descending order.
      *
       01  W-MYLIST-SORT-SWITCH       PIC X VALUE 'A'.
	   88  W-MYLIST-ASCENDING     VALUE 'A'.
	   88  W-MYLIST-DESCENDING    VALUE 'D'.
      *
      * ------------------------: Used to keep track of active column
      * 			: when user clicks the column heading
      * 			: in MYLIST.
      *
       01  W-MYLIST-COLUMN-SWITCH     PIC 99 VALUE 0.
	   88  W-MYLIST-SORT-COL-1	VALUE  1.
	   88  W-MYLIST-SORT-COL-2	VALUE  2.
	   88  W-MYLIST-SORT-COL-3	VALUE  3.
	   88  W-MYLIST-SORT-COL-4	VALUE  4.
	   88  W-MYLIST-SORT-COL-5	VALUE  5.
	   88  W-MYLIST-SORT-COL-6	VALUE  6.
	   88  W-MYLIST-SORT-COL-7	VALUE  7.
	   88  W-MYLIST-SORT-COL-8	VALUE  8.
	   88  W-MYLIST-SORT-COL-9	VALUE  9.
	   88  W-MYLIST-SORT-COL-10	VALUE 10.
	   88  W-MYLIST-SORT-COL-11	VALUE 11.
	   88  W-MYLIST-SORT-COL-12	VALUE 12.
	   88  W-MYLIST-SORT-COL-13	VALUE 13.
	   88  W-MYLIST-SORT-COL-14	VALUE 14.
	   88  W-MYLIST-SORT-COL-15	VALUE 15.
      *
       01  WORK-STUFF.
	   05  WORK-RECORD-PERCENT	    PIC S9(3)V9(6) COMP-5.
	   05  WORK-RECORDS-IN-FILE	    PIC S9(9)V9(6) COMP-5.
	   05  WORK-CURRENT-KEY 	    PIC S9(9) COMP-5.
	   05  WORK-PERCENT-NUMERIC	    PIC S9(3)V9(6)
						  SIGN LEADING SEPARATE.
	   05  WORK-KEY-DISPLAY.
	     10  WORK-KEY-NUMERIC	    PIC S9(6)
						  SIGN LEADING SEPARATE.
      *%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
       PROCEDURE DIVISION.
       0100-MAIN-LINE-LOGIC SECTION.
      * -====-
       0101-INITIALIZATION.
      * 			:---------------------------------------
      * ------------------------: If the properties for your MAIN panel
      * 			:   specified you want to save the state
      * 			:   of your panels in the registry, you
      * 			:   must provide the high-order keys
      * 			:   GUI ScreenIO is to use.
      * 			:
      * 			: They are your company name and
      * 			: the name of the application, as
      * 			: shown below:
      * 			:---------------------------------------
      *
	   MOVE 'NORCOM' TO LVMAIN-COMPANY-NAME-KEY.
	   MOVE 'GUI ScreenIO Samples' TO LVMAIN-APPLICATION-NAME-KEY.

      * ------------------------: Initialize; create the main window.
      *
	   PERFORM DISPLAY-MAIN.
      *
      * ------------------------: PERFORM paragraph to handle the panel.
      *
	   PERFORM DISPLAY-LVIEW.
      *
      * ------------------------: Finished; close the main window.
      *
	   SET LVMAIN-DO-CLOSE TO TRUE.
	   PERFORM DISPLAY-MAIN.
	   STOP RUN.

      *%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
       0200-DISPLAY-PANELS SECTION.
      * -====-
       DISPLAY-MAIN.
      * 			:---------------------------------------
      * ------------------------: Display main panel to open/close
      * 			: the main window.
      * 			:---------------------------------------
      *
	   CALL 'GS' USING LVMAIN-1
			   LVMAIN-2
			   LVMAIN-3
			   LVMAIN-4.
      * -====-
       DISPLAY-LVIEW.
      * 			:---------------------------------------
      * ------------------------: Loop to display panel LVIEW and
      * 			: handle events until the end-of-loop
      * 			: condition is encountered.
      * 			:---------------------------------------
      *
	   PERFORM WITH TEST AFTER
		 UNTIL LVIEW-EVENT-CLOSE-WINDOW
		    OR LVIEW-EVENT-CLOSE-AND-STOP
      *
      * ------------------------: Call GUI ScreenIO to display LVIEW
      *
      *      Listview panel for Listview demonstrator.
      *
	     CALL 'GS' USING LVIEW-1
			     LVIEW-2
			     LVIEW-3
			     LVIEW-4

      * ------------------------: Scroll event list and post new
      * 			: event to the status display.

	     PERFORM UPDATE-EVENT-INFORMATION

      * ------------------------: This simulates different size
      * 			: listview buffers; the smaller the
      * 			: buffer, the more I/O requests
      * 			: sent back by GUI ScreenIO.
      * 			:
      * 			: It's here just for demo purposes;
      * 			: you'd have no reason to do this.
      *
	     IF LV-BUFSIZE > MYLIST-MAX
	       MOVE MYLIST-MAX TO LV-BUFSIZE
	     END-IF
	     IF LV-BUFSIZE < 2
	       MOVE 2 TO LV-BUFSIZE
	     END-IF
      *
	     EVALUATE TRUE
      *
      * ------------------------: Menu/Button event: Create the listview
      *
	       WHEN LVIEW-SET-LIST-SIZE
		 PERFORM SET-SIMULATED-LIST-SIZE
      *
      * ------------------------: Menu/Button event: Report
      * 			: Change listview to REPORT format
      *
	       WHEN LVIEW-SET-REPORT-VIEW
		 SET MYLIST-REPORT TO TRUE
      *
      * ------------------------: Menu/Button event: List
      * 			: Change listview to LIST format
      *
	       WHEN LVIEW-SET-LIST-VIEW
		 SET MYLIST-LIST TO TRUE
      *
      * ------------------------: Menu/Button event: Icon
      * 			: Change listview to ICON format
      *
	       WHEN LVIEW-SET-ICON-VIEW
		 SET MYLIST-ICON TO TRUE
      *
      * ------------------------: Menu/Button event: Small icon
      * 			: Change listview to SMALL ICON format
      *
	       WHEN LVIEW-SET-SMALLICON-VIEW
		 SET MYLIST-SMALL-ICON TO TRUE
      *
      * ------------------------: Menu/Button event: Scroll to item with
      * 			: specified key
      *
	       WHEN LVIEW-SCROLL-LV
		 IF LVIEW-START-AT > ITEM-COUNT
		   SUBTRACT 1 FROM ITEM-COUNT GIVING
		       MYLIST-SCROLL-TO-KEY
		 ELSE
		   IF LVIEW-START-AT > 0
		     MOVE LVIEW-START-AT TO MYLIST-SCROLL-TO-KEY
		   END-IF
		 END-IF
      *
      * ------------------------: Menu/Button event: Default
      * 			: Sets default caching
      *
	       WHEN LVIEW-SET-DEFAULT-CACHE
		 SET MYLIST-DEFAULT-CACHE TO TRUE
      *
      * ------------------------: Menu/Button event: Expanding
      * 			: Set ACCUMULATE caching
      *
	       WHEN LVIEW-SET-ACCUMULATE-CACHE
		 SET MYLIST-ACCUMULATE-CACHE TO TRUE
      *
      * ------------------------: Menu/Button event: Preload
      * 			: Set PRELOAD caching
      *
	       WHEN LVIEW-SET-PRELOAD-CACHE
		 SET MYLIST-PRELOAD-CACHE TO TRUE
      *
      * ------------------------: Selected item changed in list
      * 			: MYLIST (we don't do anything special
      * 			: in this demo)
      *
	       WHEN MYLIST-B
		 PERFORM LV-MYLIST-SELECTION-CHANGE
      *
      * ------------------------: MANDATORY listview event:
      * 			: User dragged the scrollbar thumb to
      * 			: another point in the list.
      *
	       WHEN MYLIST-START-AT
		 PERFORM LV-MYLIST-START-AT-PERCENT
      *
      * ------------------------: MANDATORY listview event:
      * 			: User scrolled a little beyond the
      * 			: LAST record in the cache.
      * 			:
      * 			: Position file to record with the key
      * 			: MYLIST-GET-FROM-KEY,
      * 			: then read FORWARD, loading records
      * 			: to the list.
      *
	       WHEN MYLIST-GET-NEXT
		 PERFORM MYLIST-POSITION-TO-KEY
		   PERFORM MYLIST-BROWSE-FORWARD
      *
      * ------------------------: MANDATORY listview event:
      * 			: User scrolled a little before the
      * 			: FIRST record in the cache.
      * 			:
      * 			: Position file to record with the key
      * 			: MYLIST-GET-FROM-KEY,
      * 			: then read BACKWARD, loading records
      * 			: to the list.
      *
	       WHEN MYLIST-GET-PRIOR
		 PERFORM MYLIST-POSITION-TO-KEY
		   PERFORM MYLIST-BROWSE-BACKWARD
      *
      * ------------------------: Optional listview event:
      * 			: User double-clicked an item.
      *
	       WHEN MYLIST-DBLCLICK
		 PERFORM LV-MYLIST-DBLCLICK
      *
      * ------------------------: Optional listview event:
      * 			: User changed column 1 of an item.
      *
	       WHEN MYLIST-EDITED
		 PERFORM LV-MYLIST-EDITED
      *
      * ------------------------: Optional listview event:
      * 			: User clicked the heading of a column.
      *
	       WHEN MYLIST-CLICKCOL1
		 PERFORM LV-MYLIST-CLICKCOL1
      *
      * ------------------------: Optional listview event:
      * 			: Not implemented.

	       WHEN MYLIST-SELECTION
		 PERFORM LV-MYLIST-SELECTION
      *
      * ------------------------: LVIEW-EVENT-CLOSE-AND-STOP is a
      * 			: request to close the application,
      * 			: returned when the user:
      * 			:
      * 			: - Clicks the "X" box on the MAIN panel
      * 			:
      * 			: - Selects Close from the window system
      * 			:   menu (by clicking the small icon at
      * 			:   the left edge of the MAIN title bar)
      * 			:
      * 			: - Presses Alt+F4
      *
	       WHEN LVIEW-EVENT-CLOSE-AND-STOP
		 CONTINUE
      *
      * ------------------------: All other events will be ignored by
      * 			: this WHEN OTHER clause.
      *
	       WHEN OTHER
		 CONTINUE

	     END-EVALUATE
	   END-PERFORM.
      * -====-
       LISTVIEW-MYLIST SECTION.
      *
      *  Notes regarding listview programming.
      *
      *  First, you should definitely read the documentation regarding
      *  listviews, particularly regarding the three "mandatory" events
      *  listview-GET-NEXT, listview-GET-PRIOR, and listview-START-AT.
      *
      *  Your program absolutely MUST handle these events correctly,
      *  and it must supply the percentage each record is along the
      *  keypath; that is, how far you are into the file.
      *
      *  This generated code contains a fairly complete structure
      *  for handling a listview, including some neat tricks like
      *  how to redisplay the listview in a different order when the
      *  user clicks a column heading.
      *
      *  This code assumes that you will use an I/O subroutine to
      *  actually obtain the data.  It's always better to do this,
      *  than to embed I/O statements inline with your program
      *  because it localizes all of your I/O logic and also lets
      *  you use file systems other than COBOL ISAM with a minimum
      *  of difficulty converting your application.
      *
      *  --> See the SAMPLE APPLICATION <--
      *
      *  You should compile and play with the sample name/address
      *  application that we provide with GUI ScreenIO to see how
      *  to implement a listview application.  It may be extremely
      *  helpful to run the sample using your interactive COBOL
      *  debugger to understand how it works.
      *
      *  The sample name/address application includes an I/O subroutine
      *  for COBOL ISAM that shows how you can simulate percentages
      *  along a keypath, and how to position your file approximately
      *  to a percentage along a keypath.  It works quite well,
      *  particularly if the keys are uniformly distributed.
      *
      *  The techniques we demonstrate in the sample application can
      *  also be applied to improve performance with file systems
      *  (such as Btrieve) which support percentages, but not well;
      *  e.g., the percentages are not always consistent or in
      *  order.  This can cause problems when using a listview, since
      *  the listview requires that the percentages be in ascending
      *  order.
      *
      *  --> Note regarding percentages <--
      *
      *  This generated code assumes a file system that doesn't
      *  support percentages very well.  Therefore, it loads the
      *  percentage to the invisible key, and passes it to the
      *  I/O subroutine when it does I/O because the I/O logic
      *  uses the passed-in percentage to calculate the percentage
      *  of the record(s) it reads and passes back to this program.
      *
      *  If your file system provides accurate percentages, you do
      *  not need to pass percentages to the I/O routine or to
      *  save them in your invisible key.
      * -====-
       LV-MYLIST-DBLCLICK.
      * 			:---------------------------------------
      * ------------------------: User double-clicked an item in the
      * 			: list.  The listview returns the key
      * 			: of the selected item in
      * 			: MYLIST-SEL1-KEY.
      * 			:
      * 			: Usually, you'd pass the key to a
      * 			: subroutine to inquire/update, then
      * 			: when it returns, restart the list to
      * 			: show the updated item, like this:
      * 			:---------------------------------------
      *
	    MOVE MYLIST-SEL1-KEY TO WORK-CURRENT-KEY.

      * ------------------------: Simulate reading the record and
      * 			: updating it; all we really do is
      * 			: plug the word "Update" into the
      * 			: listview's buffer in this demo...
      *
	   PERFORM MYLIST-LOAD-RECORD.
      *
	   STRING 'Update ' MYLIST--KEY (MYLIST-IDX)
	       DELIMITED SIZE INTO MYLIST-COL1 (MYLIST-IDX).
      *
	   SET MYLIST-RESET TO TRUE.
	   MOVE MYLIST-TOP-OF-LIST-KEY
	     TO MYLIST-GET-FROM-KEY
		MYLIST-SCROLL-TO-KEY.
      *
	   PERFORM MYLIST-POSITION-TO-KEY.
	   PERFORM MYLIST-BROWSE-FORWARD.
      * -====-
       LV-MYLIST-EDITED.
      * 			:---------------------------------------
      * ------------------------: User slow-clicked an item in the list
      * 			: and changed the contents of column 1.
      * 			:
      * 			: MYLIST-SEL1-KEY
      * 			: contains the key of the item, and
      * 			: MYLIST-REC1-COL1
      * 			: contains the new content of column 1.
      * 			:
      * 			: Usually, you'd update the record and
      * 			: load only the updated item to the
      * 			: list; since the key will match the
      * 			: already-cached record, GUI ScreenIO
      * 			: will simply update the cache.
      * 			:---------------------------------------
      *
      *--> MOVE MYLIST-SEL1-KEY TO record-primary-key.
      *--> SET io-command-READ-WITH-LOCK TO TRUE
      *--> CALL 'io-subroutine' USING io-commands
      *-->			      record-buffer.
      *--> IF successful-read
      *-->   MOVE MYLIST-REC1-COL1 TO record-field1
      *-->   SET io-command-REWRITE TO TRUE
      *-->   CALL 'io-subroutine' USING io-commands
      *-->				record-buffer
      *-->   IF successful-read
      * 			: Load the changed record to the list:
	       SET MYLIST-IDX TO 1
	       PERFORM MYLIST-LOAD-RECORD.
      * -====-
       LV-MYLIST-CLICKCOL1.
      * 			:---------------------------------------
      * ------------------------: User clicked the heading of a column.
      * 			:
      * 			: If the column is an alternate key,
      * 			:   restart the list, loading it in the
      * 			:   opposite direction; e.g., read or
      * 			:   sort the list in the reverse order.
      * 			:---------------------------------------
      *
	   IF W-MYLIST-SORT-COL-1
	     IF W-MYLIST-ASCENDING
	       SET W-MYLIST-DESCENDING TO TRUE
	     ELSE
	       SET W-MYLIST-ASCENDING TO TRUE
	     END-IF
	   ELSE
	     SET W-MYLIST-SORT-COL-1 TO TRUE
	     SET W-MYLIST-ASCENDING TO TRUE.

	   SET MYLIST-RESET TO TRUE.
	   MOVE 0 TO MYLIST-START-AT-PERCENT.
	   PERFORM LV-MYLIST-START-AT-PERCENT.
      * -====-
       LV-MYLIST-SELECTION-CHANGE.
      * 			:---------------------------------------
      * ------------------------: User selected a different item in the
      * 			: list.  The listview returns the key
      * 			: of the selected item in
      * 			: MYLIST-SEL1-KEY.
      * 			:
      * 			: You might use this to display more
      * 			: data about the selected item...
      * 			:---------------------------------------
      *
      *--> MOVE MYLIST-SEL1-KEY TO record-primary-key.
      *--> SET io-command-READ TO TRUE
      *--> CALL 'io-subroutine' USING io-commands
      *-->			      record-buffer.
      *--> IF successful-read
      *-->   MOVE record-data TO LVIEW fields.
      * -====-
       LV-MYLIST-SELECTION.
      * 			:---------------------------------------
      * ------------------------: Not implemented.
      * 			:---------------------------------------
      * -====-
       LV-MYLIST-START-AT-PERCENT.
      * 			:---------------------------------------
      * ------------------------: Position to specified percentage and
      * 			: load data from that point.
      * 			:---------------------------------------

      * ------------------------: Simulated I/O to start a browse
      * 			: at a specific percentage (that is,
      * 			: the scrollbar thumb position).
      *
	   MOVE MYLIST-START-AT-PERCENT TO WORK-PERCENT-NUMERIC.
	   STRING WORK-PERCENT-NUMERIC (1:4)
	       '.'
	       WORK-PERCENT-NUMERIC (5:6) DELIMITED SIZE
		INTO LV-PERCENT-VAL (LV-PERCENT-IDX).
      *
      * 			: If 100 percent record is requested,
      * 			:   load it from the bottom up by
      * 			:   starting at the last record and
      * 			:   reading backwards
      * 			: else
      * 			:   calculate key value based on the
      * 			:   percentage in MYLIST-REC1-PERCENT
      * 			:   and read forward.
      *
	   IF MYLIST-START-AT-PERCENT NOT < 100
	     MOVE WORK-RECORDS-IN-FILE TO WORK-CURRENT-KEY
	     PERFORM MYLIST-BROWSE-BACKWARD
	   ELSE
	     COMPUTE WORK-CURRENT-KEY = 1 +
		 ((WORK-RECORDS-IN-FILE * MYLIST-START-AT-PERCENT) /
		 100)
	     PERFORM MYLIST-BROWSE-FORWARD.
      * -====-
       MYLIST-POSITION-TO-KEY.
      * 			:---------------------------------------
      * ------------------------: Extract the primary key from the key
      * 			: returned by listview, then position
      * 			: file to that key for GET-NEXT/PRIOR.
      * 			:---------------------------------------
      *
		 MOVE MYLIST-GET-FROM-KEY TO WORK-CURRENT-KEY.
      * -====-
       MYLIST-BROWSE-FORWARD.
      * 			:---------------------------------------
      * ------------------------: File is positioned; read forward
      * 			: and load records to the listview.
      * 			:---------------------------------------
      *
      * ------------------------: Simulate reading forward; GS will
      * 			: return the key of the last item
      * 			: in the cache, so you can start the
      * 			: browse with that record and
      * 			: continue.  You must place the
      * 			: record with the starting key back
      * 			: to GS as the first in your block
      * 			: so that GS can match it to its cache
      * 			: to confirm this is a contiguous read.
      *
      * ------------------------: If the CURRENT-KEY is > 0
      * 			:   simulate reading the file and
      * 			:   filling the listview buffer;
      * 			:   increment the key to simulate
      * 			:   reading file forward.
      *
	   IF WORK-CURRENT-KEY > 0
	     PERFORM WITH TEST AFTER
		   VARYING MYLIST-IDX FROM 1 BY 1
		   UNTIL MYLIST-IDX NOT < LV-BUFSIZE
		   OR WORK-CURRENT-KEY > WORK-RECORDS-IN-FILE
	       PERFORM MYLIST-LOAD-RECORD
	       ADD 1 TO WORK-CURRENT-KEY
	     END-PERFORM.
      * -====-
       MYLIST-BROWSE-BACKWARD.
      * 			:---------------------------------------
      * ------------------------: File is positioned; read backward
      * 			: and load records to the listview.
      * 			:---------------------------------------
      *
      * ------------------------: Simulate reading backwards; the rules
      * 			: are the same as for BROWSE-FORWARD.
      *
      * 			: The last key in the cache is passed
      * 			: to you in mylist-SEL1-KEY.  You
      * 			: position your file to this key and
      * 			: read records backwards from that
      * 			: point (including the given key),
      * 			: loading them to your listview buffer
      * 			: from the bottom up.
      *
      * ------------------------: If the CURRENT-KEY is > 0
      * 			:   simulate reading the file and
      * 			:   filling the listview buffer;
      * 			:   decrement the key to simulate
      * 			:   reading file backwards.
      *
	   PERFORM WITH TEST AFTER
		 VARYING MYLIST-IDX FROM LV-BUFSIZE BY -1
		 UNTIL MYLIST-IDX NOT > 1
		 OR WORK-CURRENT-KEY < 1
	     PERFORM MYLIST-LOAD-RECORD
	     ADD -1 TO WORK-CURRENT-KEY
	   END-PERFORM.
      * -====-
       MYLIST-LOAD-RECORD.
      * 			:---------------------------------------
      * ------------------------: Load record data to listview fields.
      * 			:---------------------------------------
      * 			:---------------------------------------
      * ------------------------: Simulates reading a record, sort of...
      * 			:---------------------------------------
      *
      * 			: Load the key to the listview buffer
      * 			: so that GUI ScreenIO can pass back
      * 			: the key of a record when necessary.
      *
	   MOVE WORK-CURRENT-KEY TO MYLIST--KEY (MYLIST-IDX).
      *
      * 			: You MUST tell GUI ScreenIO the
      * 			: percentage along your file of each
      * 			: record.  GUI ScreenIO uses this to
      * 			: determine the size of your file and
      * 			: to correctly set the scrollbar
      * 			: parameters.
      * 			:
      * 			: The percentage of your FIRST
      * 			: record MUST be set to ZERO percent.
      * 			:
      * 			: The percentage of your LAST record
      * 			: MUST be 100 percent.
      * 			:
      * 			: Note:  Most database packages report
      * 			: the record's percentage along the key
      * 			: path so you don't need to calculate it
      * 			: unless you're using ISAM, where you
      * 			: will need to somehow figure it out...
      * 			:
      * 			: The percentage should be as accurate
      * 			: as you can provide...
      *
	   IF WORK-CURRENT-KEY < WORK-RECORDS-IN-FILE
	     COMPUTE WORK-RECORD-PERCENT =
		 ((WORK-CURRENT-KEY - 1)* 100) / WORK-RECORDS-IN-FILE
	   ELSE
	     MOVE 100 TO WORK-RECORD-PERCENT.
      *
	   MOVE WORK-RECORD-PERCENT TO MYLIST--PERCENT (MYLIST-IDX)
      *
      * ------------------------: Load the display data to the buffer.
      * 			: In this case, we just display the
      * 			: Item number and the percentage of
      * 			: the given record.
      *
	   STRING 'Item ' MYLIST--KEY (MYLIST-IDX)
	       DELIMITED SIZE INTO MYLIST-COL1 (MYLIST-IDX).
	   MOVE MYLIST--PERCENT (MYLIST-IDX)
	       TO MYLIST-COL2 (MYLIST-IDX).
      *%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
       0200-DEMO-HOUSEKEEPING SECTION.
      * 			:---------------------------------------
      * ------------------------: Note:  The following code is here
      * 			: only to display information about
      * 			: listview events in this demo.  You
      * 			: would not have this in a normal
      * 			: application!
      * 			:---------------------------------------
      * -====-
       UPDATE-EVENT-INFORMATION.

	   PERFORM SCROLL-EVENT-LIST.

	   EVALUATE TRUE
      *
	     WHEN LVIEW-SET-LIST-SIZE
	       MOVE 'Set Size' TO LV-EVENTID-VAL (LV-EVENTID-IDX)
      *
	     WHEN LVIEW-SET-REPORT-VIEW
	       MOVE 'Report' TO LV-EVENTID-VAL (LV-EVENTID-IDX)
	       PERFORM 0202-OTHER-EVENT
      *
	     WHEN LVIEW-SET-LIST-VIEW
	       MOVE 'List' TO LV-EVENTID-VAL (LV-EVENTID-IDX)
	       PERFORM 0202-OTHER-EVENT
      *
	     WHEN LVIEW-SET-ICON-VIEW
	       MOVE 'Icon ' TO LV-EVENTID-VAL (LV-EVENTID-IDX)
	       PERFORM 0202-OTHER-EVENT
      *
	     WHEN LVIEW-SET-SMALLICON-VIEW
	       MOVE 'Small icon' TO LV-EVENTID-VAL (LV-EVENTID-IDX)
	       PERFORM 0202-OTHER-EVENT
      *
	     WHEN LVIEW-SCROLL-LV
	       MOVE 'Scroll To' TO LV-EVENTID-VAL (LV-EVENTID-IDX)
	       PERFORM 0202-OTHER-EVENT
      *
	     WHEN LVIEW-SET-DEFAULT-CACHE
	       MOVE 'Default C ' TO LV-EVENTID-VAL (LV-EVENTID-IDX)
	       PERFORM 0202-OTHER-EVENT
      *
	     WHEN LVIEW-SET-ACCUMULATE-CACHE
	       MOVE 'Accumulate' TO LV-EVENTID-VAL (LV-EVENTID-IDX)
	       PERFORM 0202-OTHER-EVENT
      *
	     WHEN LVIEW-SET-PRELOAD-CACHE
	       MOVE 'Preload C ' TO LV-EVENTID-VAL (LV-EVENTID-IDX)
	       PERFORM 0202-OTHER-EVENT
      *
	     WHEN MYLIST-B
	       MOVE 'SelChange' TO LV-EVENTID-VAL (LV-EVENTID-IDX)
	       MOVE MYLIST-SEL1-KEY TO WORK-KEY-NUMERIC
	       MOVE WORK-KEY-DISPLAY TO LV-KEY1-VAL (LV-KEY1-IDX)
	       MOVE MYLIST-SEL2-KEY TO WORK-KEY-NUMERIC
	       MOVE WORK-KEY-DISPLAY TO LV-KEY2-VAL (LV-KEY2-IDX)
      *
	     WHEN MYLIST-START-AT
	       MOVE 'START-AT ' TO LV-EVENTID-VAL (LV-EVENTID-IDX)
	       MOVE MYLIST-START-AT-PERCENT TO WORK-PERCENT-NUMERIC
	       STRING WORK-PERCENT-NUMERIC (1:4)
		      '.'
		      WORK-PERCENT-NUMERIC (5:6) DELIMITED SIZE
		 INTO LV-PERCENT-VAL (LV-PERCENT-IDX)
      *
	     WHEN MYLIST-GET-NEXT
	       MOVE 'GET-NEXT ' TO LV-EVENTID-VAL (LV-EVENTID-IDX)
	       MOVE MYLIST-GET-FROM-KEY TO WORK-KEY-NUMERIC
	       MOVE WORK-KEY-DISPLAY TO LV-KEY-VAL (LV-KEY-IDX)
      *
	     WHEN MYLIST-GET-PRIOR
	       MOVE 'GET-PRIOR' TO LV-EVENTID-VAL (LV-EVENTID-IDX)
	       MOVE MYLIST-GET-FROM-KEY TO WORK-KEY-NUMERIC
	       MOVE WORK-KEY-DISPLAY TO LV-KEY-VAL (LV-KEY-IDX)
      *
	     WHEN MYLIST-DBLCLICK
	       MOVE 'DblClick ' TO LV-EVENTID-VAL (LV-EVENTID-IDX)
	       MOVE MYLIST-SEL1-KEY TO WORK-KEY-NUMERIC
	       MOVE WORK-KEY-DISPLAY TO LV-KEY1-VAL (LV-KEY1-IDX)
	       MOVE MYLIST-SEL2-KEY TO WORK-KEY-NUMERIC
	       MOVE WORK-KEY-DISPLAY TO LV-KEY2-VAL (LV-KEY2-IDX)
      *
	     WHEN MYLIST-EDITED
	       MOVE 'Edited   ' TO LV-EVENTID-VAL (LV-EVENTID-IDX)
	       MOVE MYLIST-SEL1-KEY TO WORK-KEY-NUMERIC
	       MOVE WORK-KEY-DISPLAY TO LV-KEY1-VAL (LV-KEY1-IDX)
	       MOVE WORK-KEY-DISPLAY TO LV-KEY2-VAL (LV-KEY2-IDX)
      *
	     WHEN MYLIST-CLICKCOL1
	       MOVE 'ClickCol1' TO LV-EVENTID-VAL (LV-EVENTID-IDX)
	       MOVE MYLIST-SEL1-KEY TO WORK-KEY-NUMERIC
	       MOVE WORK-KEY-DISPLAY TO LV-KEY1-VAL (LV-KEY1-IDX)
	       MOVE MYLIST-SEL1-KEY TO WORK-KEY-NUMERIC
	       MOVE WORK-KEY-DISPLAY TO LV-KEY2-VAL (LV-KEY2-IDX)

	     WHEN MYLIST-SELECTION
	       CONTINUE
      *
	     WHEN OTHER
	       MOVE 'Other' TO LV-EVENTID-VAL (LV-EVENTID-IDX)
	       PERFORM 0202-OTHER-EVENT

	   END-EVALUATE.
      * -====-
       SET-SIMULATED-LIST-SIZE.
      * ------------------------: You need to RESET the listview
      * 			: to display a new list.
      * 			:
      * 			: The rest of this logic is just for
      * 			: this demo application...
      *
	   SET MYLIST-RESET TO TRUE.
	   MOVE ITEM-COUNT TO WORK-CURRENT-KEY.
	   IF LVIEW-START-AT > ITEM-COUNT
	     SUBTRACT 1 FROM ITEM-COUNT GIVING WORK-CURRENT-KEY
	   ELSE
	     IF LVIEW-START-AT > 0
	       MOVE LVIEW-START-AT TO WORK-CURRENT-KEY
	     ELSE
	       MOVE 1 TO WORK-CURRENT-KEY.
      *
	   MOVE WORK-CURRENT-KEY TO MYLIST-SCROLL-TO-KEY.
      *
      * ------------------------: If the item count is zero,
      * 			:   no need to do anything...
      *
	   IF ITEM-COUNT > 0
	     MOVE ITEM-COUNT TO WORK-RECORDS-IN-FILE
	     PERFORM MYLIST-BROWSE-FORWARD.
      * -====-
       0202-OTHER-EVENT.
      *
	   MOVE MYLIST-SEL1-KEY TO WORK-KEY-NUMERIC.
	   MOVE WORK-KEY-DISPLAY TO LV-KEY1-VAL (LV-KEY1-IDX).
	   MOVE MYLIST-SEL2-KEY TO WORK-KEY-NUMERIC.
	   MOVE WORK-KEY-DISPLAY TO LV-KEY2-VAL (LV-KEY2-IDX).
      * -====-
       SCROLL-EVENT-LIST.
      * 			:---------------------------------------
      * ------------------------: This scrolls the list of events,
      * 			: percents, and keys so you get a
      * 			: history of what's been going on.
      * 			: You wouldn't do this in your
      * 			: program; it's just to show you how
      * 			: the listview interacts with your
      * 			: application program.
      * 			:---------------------------------------
      *
	   PERFORM
		 VARYING LV-EVENTID-IDX FROM 1 BY 1
		 UNTIL LV-EVENTID-IDX > (LV-EVENTID-MAX - 1)
	     SET LV-PERCENT-IDX
		 LV-KEY-IDX
		 LV-KEY1-IDX
		 LV-KEY2-IDX TO LV-EVENTID-IDX
	     MOVE LV-EVENTID-VAL (LV-EVENTID-IDX + 1)
		 TO LV-EVENTID-VAL (LV-EVENTID-IDX)
	     MOVE LV-PERCENT-ITM (LV-PERCENT-IDX + 1)
		 TO LV-PERCENT-ITM (LV-PERCENT-IDX)
	     MOVE LV-KEY-ITM (LV-KEY-IDX + 1)
		 TO LV-KEY-ITM (LV-KEY-IDX)
	     MOVE LV-KEY1-ITM (LV-KEY1-IDX + 1)
		 TO LV-KEY1-ITM (LV-KEY1-IDX)
	     MOVE LV-KEY2-ITM (LV-KEY2-IDX + 1)
		 TO LV-KEY2-ITM (LV-KEY2-IDX)
	   END-PERFORM.
      *
	   SET LV-EVENTID-IDX
	       LV-PERCENT-IDX
	       LV-KEY-IDX
	       LV-KEY1-IDX
	       LV-KEY2-IDX TO LV-EVENTID-MAX.
      *
	   MOVE 'n/a' TO LV-PERCENT-ITM (LV-PERCENT-IDX)
			 LV-KEY-ITM (LV-KEY-IDX)
			 LV-KEY1-ITM (LV-KEY1-IDX)
			 LV-KEY2-ITM (LV-KEY2-IDX).
